@@ -18,9 +18,37 @@ def include_operators(pg):
         (old_test, comma, testlist_safe) = pack
         return [old_test, comma] + testlist_safe
 
-    @pg.production("expr_stmt : testlist augassign_operator testlist")
-    @pg.production("expr_stmt : testlist augassign_operator yield_expr")
+    @pg.production("expr_stmt : test COLON test")
+    def alone_annotation(pack):
+        target, colon, annotation = pack
+        return {
+            "type": "standalone_annotation",
+            "target": target,
+            "annotation": annotation,  # not called "value" in case someone
+                                       # wants to work on both assignment and
+                                       # standalone annotations
+            "first_formatting": colon.hidden_tokens_before,
+            "second_formatting": colon.hidden_tokens_after,
+        }
+
+    @pg.production("expr_stmt : test COLON test EQUAL test")
     def augmented_assignment_node(pack):
+        target, colon, annotation, equal, test = pack
+        return {
+            "type": "assignment",
+            "first_formatting": equal.hidden_tokens_before if equal else [],
+            "second_formatting": equal.hidden_tokens_after if equal else [],
+            "target": target,
+            "value": test,
+            "operator": "",
+            "annotation": annotation,
+            "annotation_first_formatting": colon.hidden_tokens_before,
+            "annotation_second_formatting": colon.hidden_tokens_after,
+        }
+
+    @pg.production("expr_stmt : testlist_star_expr augassign_operator testlist")
+    @pg.production("expr_stmt : testlist_star_expr augassign_operator yield_expr")
+    def augmented_assignment_node_2(pack):
         (target, operator, value) = pack
         return {
             "type": "assignment",
@@ -28,7 +56,24 @@ def include_operators(pg):
             "second_formatting": operator.hidden_tokens_after,
             "operator": operator.value[:-1],
             "target": target,
-            "value": value
+            "value": value,
+            "annotation": {},
+            "annotation_first_formatting": [],
+            "annotation_second_formatting": [],
+        }
+
+    @pg.production("test_or_star_expr : test")
+    @pg.production("test_or_star_expr : star_expr")
+    def test_or_star_expr(pack):
+        return pack[0]
+
+    @pg.production("star_expr : STAR expr")
+    def star_expr(pack):
+        star, expr = pack
+        return {
+            "type": "star_expression",
+            "formatting": star.hidden_tokens_after,
+            "value": expr,
         }
 
     @pg.production("augassign_operator : PLUS_EQUAL")
@@ -48,8 +93,8 @@ def include_operators(pg):
         (operator,) = pack
         return operator
 
-    @pg.production("expr_stmt : testlist EQUAL yield_expr")
-    @pg.production("expr_stmt : testlist EQUAL expr_stmt")
+    @pg.production("expr_stmt : testlist_star_expr EQUAL yield_expr")
+    @pg.production("expr_stmt : testlist_star_expr EQUAL expr_stmt")
     def assignment_node(pack):
         (target, equal, value) = pack
         return {
@@ -58,7 +103,10 @@ def include_operators(pg):
             "value": value,
             "target": target,
             "first_formatting": equal.hidden_tokens_before,
-            "second_formatting": equal.hidden_tokens_after
+            "second_formatting": equal.hidden_tokens_after,
+            "annotation": {},
+            "annotation_first_formatting": [],
+            "annotation_second_formatting": [],
         }
 
     @pg.production("test : or_test IF or_test ELSE test")
@@ -245,7 +293,7 @@ def include_operators(pg):
             "type": "dot",
             "first_formatting": dot.hidden_tokens_before,
             "second_formatting": dot.hidden_tokens_after,
-        },{
+        }, {
             "type": "name",
             "value": name.value,
         }]
@@ -275,14 +323,14 @@ def include_operators(pg):
             "fourth_formatting": right.hidden_tokens_after,
         }]
 
-    @pg.production("subscript : DOT DOT DOT")
-    @pg.production("atom : DOT DOT DOT")
+    @pg.production("subscript : ELLIPSIS")
+    @pg.production("atom : ELLIPSIS")
     def subscript_ellipsis(pack):
-        (dot1, dot2, dot3) = pack
+        ellipsis = pack[0]
         return {
             "type": "ellipsis",
-            "first_formatting": dot1.hidden_tokens_after,
-            "second_formatting": dot2.hidden_tokens_after,
+            "first_formatting": ellipsis.hidden_tokens_after,
+            "second_formatting": ellipsis.hidden_tokens_after,
         }
 
     @pg.production("subscript : test")
